@@ -1,4 +1,4 @@
-/* $XdotOrg: xc/lib/font/fc/fserve.c,v 1.7 2005/07/08 19:53:05 ajax Exp $ */
+/* $XdotOrg: lib/Xfont/src/fc/fserve.c,v 1.8 2005/07/09 06:36:12 keithp Exp $ */
 /* $Xorg: fserve.c,v 1.4 2001/02/09 02:04:02 xorgcvs Exp $ */
 /*
 
@@ -130,11 +130,11 @@ static void fs_cleanup_bfont (FSBlockedFontPtr bfont);
 
 char _fs_glyph_undefined;
 char _fs_glyph_requested;
-char _fs_glyph_zero_length;
+static char _fs_glyph_zero_length;
 
 static int  generationCount;
 
-int FontServerRequestTimeout = 30 * 1000;
+static int FontServerRequestTimeout = 30 * 1000;
 
 static void
 _fs_close_server (FSFpePtr conn);
@@ -2046,41 +2046,7 @@ extern pointer serverClient;	/* This could be any number that
 				   doesn't conflict with existing
 				   client values. */
 
-int
-fs_load_all_glyphs(FontPtr pfont)
-{
-    int		err;
-    FSFpePtr	conn = (FSFpePtr) pfont->fpe->private;
-
-    /*
-     * The purpose of this procedure is to load all glyphs in the event
-     * that we're dealing with someone who doesn't understand the finer
-     * points of glyph caching...  it is called from _fs_get_glyphs() if
-     * the latter is called to get glyphs that have not yet been loaded.
-     * We assume that the caller will not know how to handle a return
-     * value of Suspended (usually the case for a GetGlyphs() caller),
-     * so this procedure hangs around, freezing the server, for the
-     * request to complete.  This is an unpleasant kluge called to
-     * perform an unpleasant job that, we hope, will never be required.
-     */
-
-    while ((err = _fs_load_glyphs(serverClient, pfont, TRUE, 0, 0, NULL)) ==
-	   Suspended)
-    {
-	if (fs_await_reply (conn) != FSIO_READY)
-	{
-	    /* Get rid of blockrec */
-	    fs_client_died(serverClient, pfont->fpe);
-	    err = BadCharRange;
-	    break;
-	}
-	fs_read_reply (pfont->fpe, serverClient);
-    }
-    return err;
-}
-
-
-int
+static int
 _fs_load_glyphs(pointer client, FontPtr pfont, Bool range_flag, 
 		unsigned int nchars, int item_size, unsigned char *data)
 {
@@ -2230,6 +2196,39 @@ _fs_load_glyphs(pointer client, FontPtr pfont, Bool range_flag,
     return fs_send_load_glyphs(client, pfont, nranges, ranges);
 }
 
+int
+fs_load_all_glyphs(FontPtr pfont)
+{
+    int		err;
+    FSFpePtr	conn = (FSFpePtr) pfont->fpe->private;
+
+    /*
+     * The purpose of this procedure is to load all glyphs in the event
+     * that we're dealing with someone who doesn't understand the finer
+     * points of glyph caching...  it is called from _fs_get_glyphs() if
+     * the latter is called to get glyphs that have not yet been loaded.
+     * We assume that the caller will not know how to handle a return
+     * value of Suspended (usually the case for a GetGlyphs() caller),
+     * so this procedure hangs around, freezing the server, for the
+     * request to complete.  This is an unpleasant kluge called to
+     * perform an unpleasant job that, we hope, will never be required.
+     */
+
+    while ((err = _fs_load_glyphs(serverClient, pfont, TRUE, 0, 0, NULL)) ==
+	   Suspended)
+    {
+	if (fs_await_reply (conn) != FSIO_READY)
+	{
+	    /* Get rid of blockrec */
+	    fs_client_died(serverClient, pfont->fpe);
+	    err = BadCharRange;
+	    break;
+	}
+	fs_read_reply (pfont->fpe, serverClient);
+    }
+    return err;
+}
+
 static int
 fs_read_list(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
 {
@@ -2366,7 +2365,7 @@ fs_read_list_info(FontPathElementPtr fpe, FSBlockDataPtr blockrec)
     _fs_free_props (&binfo->info);
 
     rep = (fsListFontsWithXInfoReply *) fs_get_reply (conn, &ret);
-    if (rep == 0)
+    if (!rep || rep->type == FS_Error)
     {
 	if (ret == FSIO_BLOCK)
 	    return StillWorking;
@@ -2779,7 +2778,7 @@ _fs_send_conn_client_prefix (FSFpePtr conn)
 static int
 _fs_recv_conn_setup (FSFpePtr conn)
 {
-    int			ret;
+    int			ret = FSIO_ERROR;
     fsConnSetup		*setup;
     FSFpeAltPtr		alts;
     int			i, alt_len;
